@@ -1,6 +1,7 @@
 """Abstraction of a data set comprising multiple Molecule objects."""
 from glob import glob
 import psutil
+import warnings
 import os.path
 import multiprocess
 import numpy as np
@@ -64,7 +65,6 @@ class MoleculeSet:
             in the dataset.
         cluster(n_clusters=8, clustering_method=None, **kwargs): Cluster
             the molecules of the MoleculeSet. Implemented methods.
-                'kmedoids': for the K-Medoids algorithm.
                 'complete_linkage', 'complete':
                     Complete linkage agglomerative hierarchical
                     clustering.
@@ -106,6 +106,8 @@ class MoleculeSet:
 
         """
         self.is_verbose = is_verbose
+        if type(self.is_verbose) is int and self.is_verbose > 1:
+            warnings.warn("You have enabled debug-level logging (is_verbose>=2).")
         self.molecule_database = None
         self.descriptor = Descriptor()
         self.molecule_database, descriptors = self._get_molecule_database(
@@ -198,10 +200,10 @@ class MoleculeSet:
                 mol_property_val = None
                 if len(line_fields) > 1:
                     mol_property_val = float(line_fields[1])
-                # if self.is_verbose:
-                #     print(
-                #         f"Processing {smile} " f"({count + 1}/" f"{len(smiles_data)})"
-                #     )
+                if type(self.is_verbose) is int and self.is_verbose > 1:
+                    print(
+                        f"Processing {smile} " f"({count + 1}/" f"{len(smiles_data)})"
+                    )
                 mol_text = smile
                 try:
                     molecule_database.append(
@@ -252,12 +254,12 @@ class MoleculeSet:
                 # currently handles one response
                 responses = database_df[response_col].values.flatten()
             for mol_id in database_descriptor_df.index:
-                # if self.is_verbose:
-                #     print(
-                #         f"Processing "
-                #         f"({mol_id + 1}/"
-                #         f"{len(database_descriptor_df.index)})"
-                #     )
+                if type(self.is_verbose) is int and self.is_verbose > 1:
+                    print(
+                        f"Processing "
+                        f"({mol_id + 1}/"
+                        f"{len(database_descriptor_df.index)})"
+                    )
                 mol_smile = mol_smiles[mol_id] if mol_smiles is not None else None
                 mol_text = mol_names[mol_id] if mol_names is not None else mol_smile
                 mol_property_val = responses[mol_id] if responses is not None else None
@@ -362,7 +364,7 @@ class MoleculeSet:
             ):  # pragma: no cover
                 # make a local copy of the overall similarity matrix
                 local_similarity_matrix = np.zeros(shape=(n_mols, n_mols))
-                if self.is_verbose:
+                if type(self.is_verbose) is int and self.is_verbose > 1:
                     print(
                         "thread",
                         thread_idx,
@@ -379,13 +381,13 @@ class MoleculeSet:
                 for source_mol_id, molecule in enumerate(self.molecule_database):
                     if source_mol_id >= start_idx and source_mol_id < end_idx:
                         for target_mol_id in range(0, n_mols):
-                            # if self.is_verbose:
-                            #     print(
-                            #         f"thread {thread_idx} computing similarity "
-                            #         f"of molecule num "
-                            #         f"{target_mol_id + 1} "
-                            #         f"against {source_mol_id + 1}"
-                            #     )
+                            if type(self.is_verbose) is int and self.is_verbose > 1:
+                                print(
+                                    f"thread {thread_idx} computing similarity "
+                                    f"of molecule num "
+                                    f"{target_mol_id + 1} "
+                                    f"against {source_mol_id + 1}"
+                                )
                             # diagonal entry
                             if target_mol_id == source_mol_id:
                                 local_similarity_matrix[
@@ -453,11 +455,11 @@ class MoleculeSet:
             # serial implementation
             for source_mol_id, molecule in enumerate(self.molecule_database):
                 for target_mol_id in range(n_mols):
-                    # if self.is_verbose:
-                    #     print(
-                    #         "Computing similarity of molecule num "
-                    #         f"{target_mol_id + 1} against {source_mol_id + 1}"
-                    #     )
+                    if type(self.is_verbose) is int and self.is_verbose > 1:
+                        print(
+                            "Computing similarity of molecule num "
+                            f"{target_mol_id + 1} against {source_mol_id + 1}"
+                        )
                     try:
                         similarity_matrix[
                             source_mol_id, target_mol_id
@@ -622,7 +624,7 @@ class MoleculeSet:
             "perplexity": kwargs.get("perplexity", 30),
             "early_exaggeration": kwargs.get("early_exaggeration", 12),
             "learning_rate": kwargs.get("learning_rate", 200),
-            "n_iter": kwargs.get("n_iter", 1000),
+            "max_iter": kwargs.get("max_iter", 1000),
             "n_iter_without_progress": kwargs.get("n_iter_without_progress", 300),
             "min_grad_norm": kwargs.get("min_grad_norm", 1e-7),
             "init": kwargs.get("init", "random"),
@@ -631,7 +633,12 @@ class MoleculeSet:
             "angle": kwargs.get("angle", 0.5),
             "n_jobs": kwargs.get("n_jobs", None),
         }
-        embedding = TSNE(metric="precomputed", **params)
+        try:
+            embedding = TSNE(metric="precomputed", **params)
+        except TypeError:
+            params.pop("max_iter")
+            params["n_iter"] = kwargs.get("n_iter", 1000)
+            embedding = TSNE(metric="precomputed", **params)
         dissimilarity_matrix = self.get_distance_matrix()
         X = embedding.fit_transform(dissimilarity_matrix)
         if not get_component_info:
@@ -994,10 +1001,6 @@ class MoleculeSet:
             clustering_method (str): Clustering algorithm to use. Default is
                 None in which case the algorithm is chosen from the
                 similarity measure in use. Implemented clustering_methods are:
-                'kmedoids': for the K-Medoids algorithm [1].
-                    This method is useful
-                    when the molecular descriptors are continuous / Euclidean
-                    since it relies on the existence of a sensible medoid.
                 'complete_linkage', 'complete':
                     Complete linkage agglomerative hierarchical clustering [2].
                 'average_linkage', 'average':
@@ -1010,7 +1013,6 @@ class MoleculeSet:
             kwargs (keyword args): Key word arguments to supply to clustering
                 algorithm. See the documentation pages
                 listed below for these arguments:
-                'kmedoids': https://scikit-learn-extra.readthedocs.io/en/stable/generated/sklearn_extra.cluster.KMedoids.html
                 'complete_linkage', 'average_linkage', 'single_linkage', 'ward'
                     : https://scikit-learn.org/stable/modules/generated/sklearn.cluster.AgglomerativeClustering.html
 
@@ -1034,7 +1036,7 @@ class MoleculeSet:
                 "meaningful results."
             )
         if (
-            clustering_method == "kmedoids" or clustering_method == "ward"
+            clustering_method == "ward"
         ) and self.similarity_measure.type_ == "discrete":
             print(
                 f"{clustering_method} cannot be used with "
@@ -1044,7 +1046,7 @@ class MoleculeSet:
             clustering_method = None
         if clustering_method is None:
             if self.similarity_measure.type_ == "continuous":
-                clustering_method = "kmedoids"
+                clustering_method = "ward"
             else:
                 clustering_method = "complete_linkage"
         self.clusters_ = Cluster(
