@@ -1,16 +1,18 @@
 """This module contains methods to featurize molecules."""
+
 import numpy as np
 from rdkit.Chem import rdmolops
 from rdkit import Chem
 from rdkit import DataStructs
-from rdkit.Chem import AllChem
+from rdkit.Chem import rdFingerprintGenerator
 from rdkit.Chem.Fingerprints import FingerprintMols
 from rdkit.Chem import MACCSkeys
 from rdkit.Chem.AtomPairs import Pairs, Torsions
 from rdkit.DataStructs import cDataStructs
 from aimsim.utils.ccbmlib_fingerprints import generate_fingerprints
 from padelpy import from_smiles
-from aimsim.utils.extras import requires_mordred
+from mhfp.encoder import MHFPEncoder
+from mordred import Calculator, descriptors
 
 
 from ..exceptions import (
@@ -53,10 +55,7 @@ class Descriptor:
 
         """
         if self.check_init() is False:
-            raise NotInitializedError(
-                "Descriptor value not generated. Use "
-                "make_fingerprint() to initialize it."
-            )
+            raise NotInitializedError("Descriptor value not generated. Use " "make_fingerprint() to initialize it.")
         if not hasattr(self, "numpy_"):
             self.numpy_ = np.zeros((0,), dtype=np.int8)
             DataStructs.ConvertToNumpyArray(self.rdkit_, self.numpy_)
@@ -76,15 +75,9 @@ class Descriptor:
 
         """
         if self.check_init() is False:
-            raise NotInitializedError(
-                "Descriptor value not generated. Use "
-                "make_fingerprint() to initialize it."
-            )
+            raise NotInitializedError("Descriptor value not generated. Use " "make_fingerprint() to initialize it.")
         if not hasattr(self, "rdkit_"):
-            raise ValueError(
-                "Attempting to convert arbitrary numpy array "
-                "to rdkit bit vector is not supported"
-            )
+            raise ValueError("Attempting to convert arbitrary numpy array " "to rdkit bit vector is not supported")
         return self.rdkit_
 
     def check_init(self):
@@ -94,10 +87,7 @@ class Descriptor:
             (bool): True if object is initialized.
 
         """
-        return (
-            getattr(self, "numpy_", None) is not None
-            or getattr(self, "rdkit_", None) is not None
-        )
+        return getattr(self, "numpy_", None) is not None or getattr(self, "rdkit_", None) is not None
 
     def _set_morgan_fingerprint(self, molecule_graph, radius, n_bits, **kwargs):
         """Set the descriptor to a morgan fingerprint.
@@ -111,15 +101,12 @@ class Descriptor:
                 as count.
 
         """
-        self.rdkit_ = AllChem.GetMorganFingerprintAsBitVect(
-            molecule_graph, radius, nBits=n_bits, **kwargs
-        )
+        fpg = rdFingerprintGenerator.GetMorganGenerator(radius=radius, fpSize=n_bits, **kwargs)
+        self.rdkit_ = fpg.GetFingerprint(molecule_graph)
         self.label_ = "morgan_fingerprint"
         self.params_ = {"radius": radius, "n_bits": n_bits}
 
-    def _set_rdkit_topological_fingerprint(
-        self, molecule_graph, min_path, max_path, **kwargs
-    ):
+    def _set_rdkit_topological_fingerprint(self, molecule_graph, min_path, max_path, **kwargs):
         """Set the descriptor to a topological fingerprint.
 
         Args:
@@ -141,9 +128,8 @@ class Descriptor:
                 f"greater than the minimum path "
                 f"used for fingerprint."
             )
-        self.rdkit_ = rdmolops.RDKFingerprint(
-            molecule_graph, minPath=min_path, maxPath=max_path
-        )
+        fpg = rdFingerprintGenerator.GetRDKitFPGenerator(minPath=min_path, maxPath=max_path, **kwargs)
+        self.rdkit_ = fpg.GetFingerprint(molecule_graph)
         self.label_ = "topological_fingerprint"
         self.params_ = {"min_path": min_path, "max_path": max_path}
 
@@ -161,11 +147,8 @@ class Descriptor:
             self.numpy_ = np.array(all_desc[descriptor])
             self.label_ = descriptor
         except Exception as e:
-            raise RuntimeError(
-                f"Unable to retrieve PaDELPy Descriptor '{descriptor}'. Is it a valid descriptor?"
-            )
+            raise RuntimeError(f"Unable to retrieve PaDELPy Descriptor '{descriptor}'. Is it a valid descriptor?")
 
-    @requires_mordred
     def _set_mordred_descriptor(self, molecule_graph, descriptor, **kwargs):
         """Set the value of numpy_ to the descriptor as indicated by descriptor.
 
@@ -186,7 +169,7 @@ class Descriptor:
         except KeyError:
             raise MordredCalculatorError(
                 """Mordred descriptor calculator unable to calculate descriptor \"{}\",
-                ensure correct name is used (https://mordred-descriptor.github.io/documentation/master/descriptors.html).""".format(
+                ensure correct name is used (https://jacksonburns.github.io/mordred-community/descriptors.html).""".format(
                     descriptor
                 )
             )
@@ -200,7 +183,7 @@ class Descriptor:
 
         """
         # returns an ExplicitBitVect
-        self.rdkit_ = FingerprintMols.FingerprintMol(molecule_graph)
+        self.rdkit_ = FingerprintMols.FingerprintMol(molecule_graph, **kwargs)
         self.label_ = "daylight_fingerprint"
         self.params_ = {}
 
@@ -259,9 +242,28 @@ class Descriptor:
         self.label_ = descriptor
         self.params_ = {}
 
-    def make_fingerprint(
-        self, molecule_graph, fingerprint_type, fingerprint_params=None
-    ):
+    def _set_minhash_fingerprint(self, molecule_graph, **kwargs):
+        """Set the descriptor to the minhash fingerprint.
+
+        Args:
+        molecule_graph (RDKIT object): Graph of molecule to be fingerprinted.
+
+        """
+        mhfp_encoder = MHFPEncoder(
+            n_permutations=kwargs["n_permutations"],
+            seed=kwargs["seed"],
+        )
+        fp = mhfp_encoder.encode_mol(
+            molecule_graph,
+            radius=kwargs["radius"],
+            rings=kwargs["rings"],
+            kekulize=kwargs["kekulize"],
+        )
+        self.numpy_ = fp
+        self.label_ = "minhash_fingerprint"
+        self.params_ = kwargs
+
+    def make_fingerprint(self, molecule_graph, fingerprint_type, fingerprint_params=None):
         """Make fingerprint of a molecule based on a graph representation.
         Set the state of the descriptor to this fingerprint.
 
@@ -280,12 +282,20 @@ class Descriptor:
             morgan_params = {"radius": 3, "n_bits": 1024}
             morgan_params.update(fingerprint_params)
             self._set_morgan_fingerprint(molecule_graph=molecule_graph, **morgan_params)
+        elif fingerprint_type == "minhash_fingerprint":
+            minhash_params = {
+                "n_permutations": 2048,
+                "seed": 42,
+                "radius": 3,
+                "rings": True,
+                "kekulize": True,
+            }
+            minhash_params.update(fingerprint_params)
+            self._set_minhash_fingerprint(molecule_graph=molecule_graph, **minhash_params)
         elif fingerprint_type == "topological_fingerprint":
             topological_params = {"min_path": 1, "max_path": 7}
             topological_params.update(fingerprint_params)
-            self._set_rdkit_topological_fingerprint(
-                molecule_graph=molecule_graph, **topological_params
-            )
+            self._set_rdkit_topological_fingerprint(molecule_graph=molecule_graph, **topological_params)
         elif fingerprint_type == "daylight_fingerprint":
             daylight_params = {
                 "minPath": 1,
@@ -297,9 +307,7 @@ class Descriptor:
                 "minSize": 64,
             }
             daylight_params.update(fingerprint_params)
-            self._set_daylight_fingerprint(
-                molecule_graph=molecule_graph, **daylight_params
-            )
+            self._set_daylight_fingerprint(molecule_graph=molecule_graph, **daylight_params)
         elif fingerprint_type == "maccs_keys":
             maccs_params = {}
             maccs_params.update(fingerprint_params)
@@ -307,15 +315,11 @@ class Descriptor:
         elif fingerprint_type == "atom-pair_fingerprint":
             atom_pair_fp_params = {}
             atom_pair_fp_params.update(fingerprint_params)
-            self._set_atom_pair_fingerprint(
-                molecule_graph=molecule_graph, **atom_pair_fp_params
-            )
+            self._set_atom_pair_fingerprint(molecule_graph=molecule_graph, **atom_pair_fp_params)
         elif fingerprint_type == "torsion_fingerprint":
             torsion_params = {}
             torsion_params.update(fingerprint_params)
-            self._set_torsion_fingerprint(
-                molecule_graph=molecule_graph, **torsion_params
-            )
+            self._set_torsion_fingerprint(molecule_graph=molecule_graph, **torsion_params)
         elif fingerprint_type.split(":")[0] == "mordred":
             mordred_params = {}
             self._set_mordred_descriptor(
@@ -379,18 +383,11 @@ class Descriptor:
             raise ValueError("Can only fold fingerprints")
         fingerprint = self.to_numpy()
         if len(fingerprint) < fold_to_length:
-            raise InvalidConfigurationError(
-                f"Cannot fold fingerprint of "
-                f"length {len(fingerprint)}to a "
-                f"higher length {fold_to_length}"
-            )
+            raise InvalidConfigurationError(f"Cannot fold fingerprint of " f"length {len(fingerprint)}to a " f"higher length {fold_to_length}")
         n_folds = np.log2(len(fingerprint) / fold_to_length)
         if n_folds - int(n_folds) > 0.0:
             raise InvalidConfigurationError(
-                f"Fingerprint length "
-                f"{len(fingerprint)} not "
-                f"a 2-multiple of required "
-                f"folded length {fold_to_length}"
+                f"Fingerprint length " f"{len(fingerprint)} not " f"a 2-multiple of required " f"folded length {fold_to_length}"
             )
         for _ in range(int(n_folds)):
             mid_point = int(len(fingerprint) / 2)
@@ -445,9 +442,7 @@ class Descriptor:
                 fprint2_arr,
             )
         else:
-            return fprint1_arr, fingerprint2.get_folded_fprint(
-                fold_to_length=len(fprint1_arr)
-            )
+            return fprint1_arr, fingerprint2.get_folded_fprint(fold_to_length=len(fprint1_arr))
 
     @staticmethod
     def get_supported_fprints():
@@ -475,6 +470,7 @@ class Descriptor:
             "morgan_fingerprint",
             "topological_fingerprint",
             "daylight_fingerprint",
+            "minhash_fingerprint",
             "maccs_keys",
             "atom-pair_fingerprint",
             "torsion_fingerprint",
